@@ -355,8 +355,8 @@ spell_dialog_class_init (GtkhtmlSpellDialogClass *class)
 		PROP_WORD,
 		g_param_spec_string (
 			"word",
-			_("Misspelled Word"),
-			_("The current misspelled word"),
+			"Misspelled Word",
+			"The current misspelled word",
 			NULL,
 			G_PARAM_READWRITE));
 
@@ -443,7 +443,9 @@ spell_dialog_init (GtkhtmlSpellDialog *dialog)
 
 	gtk_dialog_add_button (
 		GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+#if !GTK_CHECK_VERSION(2,90,7)
+	g_object_set (dialog, "has-separator", FALSE, NULL);
+#endif
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Spell Checker"));
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
